@@ -1,4 +1,4 @@
-;;; doric-earth-theme.el --- Minimalist light theme -*- lexical-binding:t -*-
+;;; doric-earth-theme.el --- Minimalist theme with light background and brown hues -*- lexical-binding:t -*-
 
 ;; Copyright (C) 2025  Free Software Foundation, Inc.
 
@@ -66,15 +66,15 @@
       (fg-magenta "#690f44")
       (fg-cyan "#105f66")
 
-      (bg-red "#f3c4b5")
-      (bg-green "#c8ebb0")
+      (bg-red "#f0c8b5")
+      (bg-green "#c2e3b0")
       (bg-yellow "#efe4b0")
       (bg-blue "#bac9e5")
       (bg-magenta "#e7bfd7")
       (bg-cyan "#c9e6e0"))
     "Palette of `doric-earth' theme.")
 
-  (doric-themes-define-theme doric-earth light))
+  (doric-themes-define-theme doric-earth light "Minimalist theme with light background and brown hues"))
 
 (provide 'doric-earth-theme)
 ;;; doric-earth-theme.el ends here
